@@ -12,6 +12,10 @@ def run(fast=False):
     estimator = dataset.get_model()
     train, test = dataset.as_dmd()
 
+    if fast:
+        train, _ = train.split(0.95)
+        test, _ = test.split(0.95)
+
     metric = Metrics.rmse.name
 
     pytrust = PyTrust(
@@ -32,6 +36,12 @@ def run(fast=False):
     print('\n'.join(pytrust.dataset_analysis_report.insights()))
     print("Calculating... Done")
 
+    print("Let's check for anomalies in the dataset")
+    print("Calculating...")
+    pytrust.anomalies_in_data_report.plot()
+    print('\n'.join(pytrust.anomalies_in_data_report.insights()))
+    print("Calculating... Done")
+
     print("Let's calculate score report")
     print("Calculating...")
     scoring_report = pytrust.scoring_report
