@@ -2,16 +2,16 @@ import unittest
 
 from examples.interesting_examples import adult_example, california_housing_example, kddcup99_example, \
     prediction_uncertainty_adult_example, simple_example_classification, simple_example_regression, \
-    prediction_uncertainty_california_example, titanic_example, active_learning_example
+    prediction_uncertainty_california_example, titanic_example, active_learning_example, anomalies_in_dataset_example
 
 
 class TestInterestingExamples(unittest.TestCase):
 
     def test_simple_example_cla(self):
-        simple_example_classification.run()
+        simple_example_classification.run(fast=True)
 
     def test_simple_example_reg(self):
-        simple_example_regression.run()
+        simple_example_regression.run(fast=True)
 
     # @unittest.skip("adult_dataset example - Takes time")
     def test_adult_dataset(self):
@@ -35,4 +35,7 @@ class TestInterestingExamples(unittest.TestCase):
         titanic_example.run(fast=True)
 
     def test_active_learning(self):
-        active_learning_example.run(fast=True)
\ No newline at end of file
+        active_learning_example.run(fast=True)
+
+    def test_anomalies_dataset(self):
+        anomalies_in_dataset_example.run(fast=True)
